@@ -48,14 +48,14 @@ class LayerMapping:
     "A class that maps OGR Layers to GeoDjango Models."
 
     # Acceptable 'base' types for a multi-geometry type.
-    MULTI_TYPES = {1: OGRGeomType('MultiPoint'),
-                   2: OGRGeomType('MultiLineString'),
-                   3: OGRGeomType('MultiPolygon'),
-                   OGRGeomType('Point25D').num: OGRGeomType('MultiPoint25D'),
-                   OGRGeomType('LineString25D').num: OGRGeomType('MultiLineString25D'),
-                   OGRGeomType('Polygon25D').num: OGRGeomType('MultiPolygon25D'),
-                   }
-
+    MULTI_TYPES = {
+        1: OGRGeomType('MultiPoint'),
+        2: OGRGeomType('MultiLineString'),
+        3: OGRGeomType('MultiPolygon'),
+        OGRGeomType('Point25D').num: OGRGeomType('MultiPoint25D'),
+        OGRGeomType('LineString25D').num: OGRGeomType('MultiLineString25D'),
+        OGRGeomType('Polygon25D').num: OGRGeomType('MultiPolygon25D'),
+    }
     # Acceptable Django field types and corresponding acceptable OGR
     # counterparts.
     FIELD_TYPES = {
@@ -558,10 +558,14 @@ class LayerMapping:
                             # one from the kwargs WKT, adding in additional
                             # geometries, and update the attribute with the
                             # just-updated geometry WKT.
-                            geom = getattr(m, self.geom_field).ogr
-                            new = OGRGeometry(kwargs[self.geom_field])
-                            for g in new:
-                                geom.add(g)
+                            geom_value = getattr(m, self.geom_field)
+                            if geom_value is None:
+                                geom = OGRGeometry(kwargs[self.geom_field])
+                            else:
+                                geom = geom_value.ogr
+                                new = OGRGeometry(kwargs[self.geom_field])
+                                for g in new:
+                                    geom.add(g)
                             setattr(m, self.geom_field, geom.wkt)
                         except ObjectDoesNotExist:
                             # No unique model exists yet, create.
