@@ -4,28 +4,16 @@ from importlib import import_module
 
 from django import get_version
 from django.apps import apps
+# SettingsReference imported for backwards compatibility in Django 2.2.
+from django.conf import SettingsReference  # NOQA
 from django.db import migrations
 from django.db.migrations.loader import MigrationLoader
-from django.db.migrations.serializer import serializer_factory
+from django.db.migrations.serializer import Serializer, serializer_factory
 from django.utils.inspect import get_func_args
 from django.utils.module_loading import module_dir
 from django.utils.timezone import now
 
 
-class SettingsReference(str):
-    """
-    Special subclass of string which actually references a current settings
-    value. It's treated as the value in memory, but serializes out to a
-    settings.NAME attribute reference.
-    """
-
-    def __new__(self, value, setting_name):
-        return str.__new__(self, value)
-
-    def __init__(self, value, setting_name):
-        self.setting_name = setting_name
-
-
 class OperationWriter:
     def __init__(self, operation, indentation=2):
         self.operation = operation
@@ -132,8 +120,9 @@ class MigrationWriter:
     of the migration file from it.
     """
 
-    def __init__(self, migration):
+    def __init__(self, migration, include_header=True):
         self.migration = migration
+        self.include_header = include_header
         self.needs_manual_porting = False
 
     def as_string(self):
@@ -195,10 +184,13 @@ class MigrationWriter:
         if self.migration.replaces:
             items['replaces_str'] = "\n    replaces = %s\n" % self.serialize(self.migration.replaces)[0]
         # Hinting that goes into comment
-        items.update(
-            version=get_version(),
-            timestamp=now().strftime("%Y-%m-%d %H:%M"),
-        )
+        if self.include_header:
+            items['migration_header'] = MIGRATION_HEADER_TEMPLATE % {
+                'version': get_version(),
+                'timestamp': now().strftime("%Y-%m-%d %H:%M"),
+            }
+        else:
+            items['migration_header'] = ""
 
         if self.migration.initial:
             items['initial_str'] = "\n    initial = True\n"
@@ -240,7 +232,7 @@ class MigrationWriter:
             missing_dirs.insert(0, existing_dirs.pop(-1))
             try:
                 base_module = import_module(".".join(existing_dirs))
-            except ImportError:
+            except (ImportError, ValueError):
                 continue
             else:
                 try:
@@ -278,11 +270,23 @@ class MigrationWriter:
     def serialize(cls, value):
         return serializer_factory(value).serialize()
 
+    @classmethod
+    def register_serializer(cls, type_, serializer):
+        Serializer.register(type_, serializer)
 
-MIGRATION_TEMPLATE = """\
+    @classmethod
+    def unregister_serializer(cls, type_):
+        Serializer.unregister(type_)
+
+
+MIGRATION_HEADER_TEMPLATE = """\
 # Generated by Django %(version)s on %(timestamp)s
 
-%(imports)s
+"""
+
+
+MIGRATION_TEMPLATE = """\
+%(migration_header)s%(imports)s
 
 class Migration(migrations.Migration):
 %(replaces_str)s%(initial_str)s
